@@ -22,6 +22,7 @@ use File::Spec;
 use File::Copy;
 use Digest::SHA;
 use Digest::MD5;
+use Term::ReadKey;
 
 has app  => ( is => 'ro' );
 has repo => ( is => 'ro' );
@@ -310,4 +311,17 @@ sub verify_options {
   }
 }
 
+sub read_password {
+  my ( $self, $msg ) = @_;
+  $msg ||= "Password: ";
+
+  print $msg;
+  ReadMode "noecho";
+  my $password = <STDIN>;
+  chomp $password;
+  ReadMode 0;
+  print "\n";
+  return $password;
+}
+
 1;
